==> elemental2-dom-1.2.1.jar: elemental2/dom/HTMLTextAreaElement.java <==
/*
 * Copyright 2018 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package elemental2.dom;

import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsType;

@JsType(isNative = true, namespace = JsPackage.GLOBAL)
public class HTMLTextAreaElement extends HTMLElement {
  public String accessKey;
  public boolean autofocus;
  public int cols;
  public String defaultValue;
  public boolean disabled;
  public HTMLFormElement form;
  public NodeList<HTMLLabelElement> labels;
  public int maxLength;
  public int minLength;
  public String name;
  public String placeholder;
  public boolean readOnly;
  public int rows;
  public int tabIndex;
  public int textLength;
  public String type;
  public String validationMessage;
  public ValidityState validity;
  public String value;
  public boolean willValidate;

  public native void blur();

  public native boolean checkValidity();

  public native void focus();

  public native boolean reportValidity();

  public native void select();

  public native void setCustomValidity(String message);
}

==> elemental2-dom-1.2.3.jar: elemental2/dom/HTMLTextAreaElement.java <==
/*
 * Copyright 2018 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package elemental2.dom;

import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsType;

@JsType(isNative = true, namespace = JsPackage.GLOBAL)
public class HTMLTextAreaElement extends HTMLElement {
  public String accessKey;
  public boolean autofocus;
  public int cols;
  public String defaultValue;
  public boolean disabled;
  public HTMLFormElement form;
  public NodeList<HTMLLabelElement> labels;
  public int maxLength;
  public int minLength;
  public String name;
  public String placeholder;
  public boolean readOnly;
  public int rows;
  public double selectionEnd;
  public double selectionStart;
  public int tabIndex;
  public int textLength;
  public String type;
  public String validationMessage;
  public ValidityState validity;
  public String value;
  public boolean willValidate;

  public native void blur();

  public native boolean checkValidity();

  public native void focus();

  public native boolean reportValidity();

  public native void select();

  public native void setCustomValidity(String message);

  public native void setRangeText(
      String replacement, double start, double end, String selectionMode);

  public native void setRangeText(String replacement, double start, double end);

  public native void setRangeText(String replacement, double start);

  public native void setRangeText(String replacement);

  public native void setSelectionRange(double selectionStart, double selectionEnd);
}
